# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_vra.blockdevice as __blockdevice
    blockdevice = __blockdevice
    import pulumiverse_vra.blueprint as __blueprint
    blueprint = __blueprint
    import pulumiverse_vra.catalog as __catalog
    catalog = __catalog
    import pulumiverse_vra.cloudaccount as __cloudaccount
    cloudaccount = __cloudaccount
    import pulumiverse_vra.config as __config
    config = __config
    import pulumiverse_vra.contentsource as __contentsource
    contentsource = __contentsource
    import pulumiverse_vra.datacollector as __datacollector
    datacollector = __datacollector
    import pulumiverse_vra.deployment as __deployment
    deployment = __deployment
    import pulumiverse_vra.fabric as __fabric
    fabric = __fabric
    import pulumiverse_vra.flavor as __flavor
    flavor = __flavor
    import pulumiverse_vra.image as __image
    image = __image
    import pulumiverse_vra.loadbalancer as __loadbalancer
    loadbalancer = __loadbalancer
    import pulumiverse_vra.machine as __machine
    machine = __machine
    import pulumiverse_vra.network as __network
    network = __network
    import pulumiverse_vra.project as __project
    project = __project
    import pulumiverse_vra.region as __region
    region = __region
    import pulumiverse_vra.securitygroup as __securitygroup
    securitygroup = __securitygroup
    import pulumiverse_vra.storageprofile as __storageprofile
    storageprofile = __storageprofile
    import pulumiverse_vra.zone as __zone
    zone = __zone
else:
    blockdevice = _utilities.lazy_import('pulumiverse_vra.blockdevice')
    blueprint = _utilities.lazy_import('pulumiverse_vra.blueprint')
    catalog = _utilities.lazy_import('pulumiverse_vra.catalog')
    cloudaccount = _utilities.lazy_import('pulumiverse_vra.cloudaccount')
    config = _utilities.lazy_import('pulumiverse_vra.config')
    contentsource = _utilities.lazy_import('pulumiverse_vra.contentsource')
    datacollector = _utilities.lazy_import('pulumiverse_vra.datacollector')
    deployment = _utilities.lazy_import('pulumiverse_vra.deployment')
    fabric = _utilities.lazy_import('pulumiverse_vra.fabric')
    flavor = _utilities.lazy_import('pulumiverse_vra.flavor')
    image = _utilities.lazy_import('pulumiverse_vra.image')
    loadbalancer = _utilities.lazy_import('pulumiverse_vra.loadbalancer')
    machine = _utilities.lazy_import('pulumiverse_vra.machine')
    network = _utilities.lazy_import('pulumiverse_vra.network')
    project = _utilities.lazy_import('pulumiverse_vra.project')
    region = _utilities.lazy_import('pulumiverse_vra.region')
    securitygroup = _utilities.lazy_import('pulumiverse_vra.securitygroup')
    storageprofile = _utilities.lazy_import('pulumiverse_vra.storageprofile')
    zone = _utilities.lazy_import('pulumiverse_vra.zone')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vra",
  "mod": "blockdevice/blockDevice",
  "fqn": "pulumiverse_vra.blockdevice",
  "classes": {
   "vra:blockdevice/blockDevice:BlockDevice": "BlockDevice"
  }
 },
 {
  "pkg": "vra",
  "mod": "blockdevice/snapshot",
  "fqn": "pulumiverse_vra.blockdevice",
  "classes": {
   "vra:blockdevice/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "vra",
  "mod": "blueprint/blueprint",
  "fqn": "pulumiverse_vra.blueprint",
  "classes": {
   "vra:blueprint/blueprint:Blueprint": "Blueprint"
  }
 },
 {
  "pkg": "vra",
  "mod": "blueprint/blueprintVersion",
  "fqn": "pulumiverse_vra.blueprint",
  "classes": {
   "vra:blueprint/blueprintVersion:BlueprintVersion": "BlueprintVersion"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/itemEntitlement",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/itemEntitlement:ItemEntitlement": "ItemEntitlement"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/sourceBlueprint",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/sourceBlueprint:SourceBlueprint": "SourceBlueprint"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/sourceEntitlement",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/sourceEntitlement:SourceEntitlement": "SourceEntitlement"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/aws",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/aws:Aws": "Aws"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/azure",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/azure:Azure": "Azure"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/gcp",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/gcp:Gcp": "Gcp"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/nsxt",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/nsxt:Nsxt": "Nsxt"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/nsxv",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/nsxv:Nsxv": "Nsxv"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/vSphere",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/vSphere:VSphere": "VSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/vmc",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/vmc:Vmc": "Vmc"
  }
 },
 {
  "pkg": "vra",
  "mod": "contentsource/contentSource",
  "fqn": "pulumiverse_vra.contentsource",
  "classes": {
   "vra:contentsource/contentSource:ContentSource": "ContentSource"
  }
 },
 {
  "pkg": "vra",
  "mod": "deployment/deployment",
  "fqn": "pulumiverse_vra.deployment",
  "classes": {
   "vra:deployment/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/compute",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/compute:Compute": "Compute"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/datastoreVSphere",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/datastoreVSphere:DatastoreVSphere": "DatastoreVSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/networkVSphere",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/networkVSphere:NetworkVSphere": "NetworkVSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "flavor/profile",
  "fqn": "pulumiverse_vra.flavor",
  "classes": {
   "vra:flavor/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "image/profile",
  "fqn": "pulumiverse_vra.image",
  "classes": {
   "vra:image/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "loadbalancer/loadBalancer",
  "fqn": "pulumiverse_vra.loadbalancer",
  "classes": {
   "vra:loadbalancer/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "vra",
  "mod": "machine/machine",
  "fqn": "pulumiverse_vra.machine",
  "classes": {
   "vra:machine/machine:Machine": "Machine"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/ipRange",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/ipRange:IpRange": "IpRange"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/network",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/network:Network": "Network"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/profile",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "project/project",
  "fqn": "pulumiverse_vra.project",
  "classes": {
   "vra:project/project:Project": "Project"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/aws",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/aws:Aws": "Aws"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/azure",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/azure:Azure": "Azure"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/storageProfile",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/storageProfile:StorageProfile": "StorageProfile"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/vSphere",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/vSphere:VSphere": "VSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "zone/zone",
  "fqn": "pulumiverse_vra.zone",
  "classes": {
   "vra:zone/zone:Zone": "Zone"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vra",
  "token": "pulumi:providers:vra",
  "fqn": "pulumiverse_vra",
  "class": "Provider"
 }
]
"""
)
