# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSecurityGroupRuleArgs',
]

@pulumi.input_type
class GetSecurityGroupRuleArgs:
    def __init__(__self__, *,
                 access: str,
                 direction: str,
                 ip_range_cidr: int,
                 ports: str,
                 protocol: str,
                 name: Optional[str] = None,
                 service: Optional[str] = None):
        """
        :param str name: Name of the security group.
        """
        pulumi.set(__self__, "access", access)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "ip_range_cidr", ip_range_cidr)
        pulumi.set(__self__, "ports", ports)
        pulumi.set(__self__, "protocol", protocol)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service is not None:
            pulumi.set(__self__, "service", service)

    @property
    @pulumi.getter
    def access(self) -> str:
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: str):
        pulumi.set(self, "access", value)

    @property
    @pulumi.getter
    def direction(self) -> str:
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: str):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipRangeCidr")
    def ip_range_cidr(self) -> int:
        return pulumi.get(self, "ip_range_cidr")

    @ip_range_cidr.setter
    def ip_range_cidr(self, value: int):
        pulumi.set(self, "ip_range_cidr", value)

    @property
    @pulumi.getter
    def ports(self) -> str:
        return pulumi.get(self, "ports")

    @ports.setter
    def ports(self, value: str):
        pulumi.set(self, "ports", value)

    @property
    @pulumi.getter
    def protocol(self) -> str:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the security group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[str]:
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[str]):
        pulumi.set(self, "service", value)


