# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationAwsResult',
    'AwaitableGetEnumerationAwsResult',
    'get_enumeration_aws',
    'get_enumeration_aws_output',
]

@pulumi.output_type
class GetEnumerationAwsResult:
    """
    A collection of values returned by getEnumerationAws.
    """
    def __init__(__self__, access_key=None, id=None, regions=None, secret_key=None):
        if access_key and not isinstance(access_key, str):
            raise TypeError("Expected argument 'access_key' to be a str")
        pulumi.set(__self__, "access_key", access_key)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if secret_key and not isinstance(secret_key, str):
            raise TypeError("Expected argument 'secret_key' to be a str")
        pulumi.set(__self__, "secret_key", secret_key)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> str:
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of Region names to enable provisioning on. Example: us-east-2, ap-northeast-1
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> str:
        return pulumi.get(self, "secret_key")


class AwaitableGetEnumerationAwsResult(GetEnumerationAwsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationAwsResult(
            access_key=self.access_key,
            id=self.id,
            regions=self.regions,
            secret_key=self.secret_key)


def get_enumeration_aws(access_key: Optional[str] = None,
                        secret_key: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationAwsResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for AWS cloud account.

    **Region enumeration data source for AWS, by the AWS account access key and secret key:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_aws(access_key=var["access_key"],
        secret_key=var["secret_key"])
    ```

    The region enumeration data source for AWS cloud account supports the following arguments:


    :param str access_key: Aws Access key ID.
    :param str secret_key: Aws Secret Access Key.
    """
    __args__ = dict()
    __args__['accessKey'] = access_key
    __args__['secretKey'] = secret_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationAws:getEnumerationAws', __args__, opts=opts, typ=GetEnumerationAwsResult).value

    return AwaitableGetEnumerationAwsResult(
        access_key=__ret__.access_key,
        id=__ret__.id,
        regions=__ret__.regions,
        secret_key=__ret__.secret_key)


@_utilities.lift_output_func(get_enumeration_aws)
def get_enumeration_aws_output(access_key: Optional[pulumi.Input[str]] = None,
                               secret_key: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationAwsResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for AWS cloud account.

    **Region enumeration data source for AWS, by the AWS account access key and secret key:**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_aws(access_key=var["access_key"],
        secret_key=var["secret_key"])
    ```

    The region enumeration data source for AWS cloud account supports the following arguments:


    :param str access_key: Aws Access key ID.
    :param str secret_key: Aws Secret Access Key.
    """
    ...
