# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('vra')


class _ExportableConfig(types.ModuleType):
    @property
    def access_token(self) -> Optional[str]:
        """
        The access token for API operations.
        """
        return __config__.get('accessToken')

    @property
    def insecure(self) -> Optional[bool]:
        """
        Specify whether to validate TLS certificates.
        """
        return __config__.get_bool('insecure')

    @property
    def reauthorize_timeout(self) -> Optional[str]:
        """
        Specify timeout for how often to reauthorize the access token
        """
        return __config__.get('reauthorizeTimeout')

    @property
    def refresh_token(self) -> Optional[str]:
        """
        The refresh token for API operations.
        """
        return __config__.get('refreshToken')

    @property
    def url(self) -> Optional[str]:
        """
        The base url for API operations.
        """
        return __config__.get('url')

