# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAzureResult',
    'AwaitableGetAzureResult',
    'get_azure',
    'get_azure_output',
]

@pulumi.output_type
class GetAzureResult:
    """
    A collection of values returned by getAzure.
    """
    def __init__(__self__, application_id=None, created_at=None, description=None, id=None, links=None, name=None, org_id=None, owner=None, regions=None, subscription_id=None, tags=None, tenant_id=None, updated_at=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> str:
        """
        Azure Client Application ID.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetAzureLinkResult']:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of region names that are enabled for this account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        """
        Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetAzureTagResult']:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetAzureResult(GetAzureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureResult(
            application_id=self.application_id,
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            regions=self.regions,
            subscription_id=self.subscription_id,
            tags=self.tags,
            tenant_id=self.tenant_id,
            updated_at=self.updated_at)


def get_azure(id: Optional[str] = None,
              name: Optional[str] = None,
              tags: Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureResult:
    """
    Provides a VMware vRA cloudaccount.Azure data source.

    ## Example Usage
    ### S

    **Azure cloud account data source by its id:**

    This is an example of how to read the cloud account data source using its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(id=var["vra_cloud_account_azure_id"])
    ```

    **Azure cloud account data source by its name:**

    This is an example of how to read the cloud account data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(name=var["vra_cloud_account_azure_name"])
    ```


    :param str id: The id of this Azure cloud account.
    :param str name: The name of this Azure cloud account.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "vmware", "value": "provider" } ]
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:cloudaccount/getAzure:getAzure', __args__, opts=opts, typ=GetAzureResult).value

    return AwaitableGetAzureResult(
        application_id=__ret__.application_id,
        created_at=__ret__.created_at,
        description=__ret__.description,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        regions=__ret__.regions,
        subscription_id=__ret__.subscription_id,
        tags=__ret__.tags,
        tenant_id=__ret__.tenant_id,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_azure)
def get_azure_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                     name: Optional[pulumi.Input[Optional[str]]] = None,
                     tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAzureResult]:
    """
    Provides a VMware vRA cloudaccount.Azure data source.

    ## Example Usage
    ### S

    **Azure cloud account data source by its id:**

    This is an example of how to read the cloud account data source using its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(id=var["vra_cloud_account_azure_id"])
    ```

    **Azure cloud account data source by its name:**

    This is an example of how to read the cloud account data source using its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.cloudaccount.get_azure(name=var["vra_cloud_account_azure_name"])
    ```


    :param str id: The id of this Azure cloud account.
    :param str name: The name of this Azure cloud account.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "vmware", "value": "provider" } ]
    """
    ...
