# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetStoragePolicyVSphereResult',
    'AwaitableGetStoragePolicyVSphereResult',
    'get_storage_policy_v_sphere',
    'get_storage_policy_v_sphere_output',
]

@pulumi.output_type
class GetStoragePolicyVSphereResult:
    """
    A collection of values returned by getStoragePolicyVSphere.
    """
    def __init__(__self__, cloud_account_ids=None, created_at=None, external_id=None, external_region_id=None, filter=None, id=None, links=None, name=None, org_id=None, updated_at=None):
        if cloud_account_ids and not isinstance(cloud_account_ids, list):
            raise TypeError("Expected argument 'cloud_account_ids' to be a list")
        pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Sequence[str]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region for which this entity is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetStoragePolicyVSphereLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.  Only one of 'filter', 'id', 'name' or 'region_id' must be specified.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetStoragePolicyVSphereResult(GetStoragePolicyVSphereResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStoragePolicyVSphereResult(
            cloud_account_ids=self.cloud_account_ids,
            created_at=self.created_at,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            updated_at=self.updated_at)


def get_storage_policy_v_sphere(filter: Optional[str] = None,
                                id: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStoragePolicyVSphereResult:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup fabric vSphere storage policies.

    **Fabric vSphere storage policy by Id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(id=var["fabric_storage_policy_vsphere_id"])
    ```

    **Fabric vSphere storage policy by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(filter=f"name eq '{var['name']}'")
    ```

    A fabric vSphere storage policy supports the following arguments:


    :param str filter: Search criteria to narrow down the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    :param str id: The id of the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:fabric/getStoragePolicyVSphere:getStoragePolicyVSphere', __args__, opts=opts, typ=GetStoragePolicyVSphereResult).value

    return AwaitableGetStoragePolicyVSphereResult(
        cloud_account_ids=__ret__.cloud_account_ids,
        created_at=__ret__.created_at,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_storage_policy_v_sphere)
def get_storage_policy_v_sphere_output(filter: Optional[pulumi.Input[Optional[str]]] = None,
                                       id: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStoragePolicyVSphereResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup fabric vSphere storage policies.

    **Fabric vSphere storage policy by Id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(id=var["fabric_storage_policy_vsphere_id"])
    ```

    **Fabric vSphere storage policy by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(filter=f"name eq '{var['name']}'")
    ```

    A fabric vSphere storage policy supports the following arguments:


    :param str filter: Search criteria to narrow down the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    :param str id: The id of the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    """
    ...
